@@ -97,6 +97,8 @@ static GtkWidget *create_local_db(void)
     gtk_clist_set_selection_mode(GTK_CLIST(clist), 
                                  GTK_SELECTION_BROWSE); 
     gtk_clist_column_titles_passive(GTK_CLIST(clist));
+    gtk_clist_set_column_auto_resize(GTK_CLIST(clist), 0, TRUE);
+    gtk_clist_set_column_auto_resize(GTK_CLIST(clist), 1, TRUE);
     gtk_clist_set_sort_column(GTK_CLIST(clist), 1);
     gtk_clist_set_auto_sort(GTK_CLIST(clist), TRUE);
 
@@ -146,32 +148,34 @@ GtkWidget *create_cddb_page(void)
 
     label = gtk_label_new(_("Address"));
     entry = gtk_entry_new();
-    gtk_entry_set_text(GTK_ENTRY(entry), prefs.cddb_server);
+    gtk_entry_set_text(GTK_ENTRY(entry), prefs->cddb_server);
     gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 0, 1);
     gtk_table_attach_defaults(GTK_TABLE(table), entry, 1, 3, 0, 1);
     gtk_signal_connect(GTK_OBJECT(entry), "changed",
 		       GTK_SIGNAL_FUNC(entry_cb), NULL);
 
     adj = gtk_adjustment_new(8880, 0, 65536, 1, 100, 10);
-    gtk_adjustment_set_value(GTK_ADJUSTMENT(adj), prefs.cddb_port);
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(adj), prefs->cddb_port);
     label = gtk_label_new(_("Port"));
     portw = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1, 0);
     gtk_table_attach_defaults(GTK_TABLE(table), label, 3, 4, 0, 1);
     gtk_table_attach_defaults(GTK_TABLE(table), portw, 4, 5, 0, 1);
     gtk_signal_connect(GTK_OBJECT(adj), "value_changed",
 		       GTK_SIGNAL_FUNC(port_cb), NULL);
+    gtk_signal_connect(GTK_OBJECT(adj), "changed",
+		       GTK_SIGNAL_FUNC(port_cb), NULL);
 
     cbutton = gtk_check_button_new_with_label(_("Use HTTP"));
     gtk_object_set_data(GTK_OBJECT(cbutton), "server-entry", entry);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cbutton), prefs.cddb_http);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cbutton), prefs->cddb_http);
     gtk_table_attach_defaults(GTK_TABLE(table), cbutton, 0,1, 1,2);
 
     label = gtk_label_new(_("Proxy"));
     gtk_table_attach_defaults(GTK_TABLE(table), label, 1,2, 1,2);
     entry = gtk_entry_new();
-    gtk_entry_set_text(GTK_ENTRY(entry), prefs.cddb_httpproxy);
+    gtk_entry_set_text(GTK_ENTRY(entry), prefs->cddb_httpproxy);
     gtk_table_attach_defaults(GTK_TABLE(table), entry, 2,5, 1,2);
-    if (!prefs.cddb_http) gtk_widget_set_sensitive(entry, FALSE);
+    if (!prefs->cddb_http) gtk_widget_set_sensitive(entry, FALSE);
     gtk_signal_connect(GTK_OBJECT(entry), "changed",
 		       GTK_SIGNAL_FUNC(httpproxy_cb), NULL);
 
@@ -410,21 +414,21 @@ static void remove_cb(GtkWidget *widget, GtkWidget *clist)
 
 static void entry_cb(GtkWidget *widget, gpointer data)
 {
-    prefs.cddb_server = g_strdup(gtk_entry_get_text(GTK_ENTRY(widget)));
+    prefs->cddb_server = g_strdup(gtk_entry_get_text(GTK_ENTRY(widget)));
     changed_cb(NULL, NULL);
 }
 
 static void port_cb(GtkObject *adj, gpointer data)
 {
-    prefs.cddb_port = (gint)GTK_ADJUSTMENT(adj)->value;
+    prefs->cddb_port = (gint)GTK_ADJUSTMENT(adj)->value;
     changed_cb(NULL, NULL);
 }
 
 static void use_http_cb(GtkWidget *widget, GtkWidget *entry) {
     gint val;
 
-    prefs.cddb_http = GTK_TOGGLE_BUTTON(widget)->active;
-    gtk_widget_set_sensitive(entry, prefs.cddb_http);
+    prefs->cddb_http = GTK_TOGGLE_BUTTON(widget)->active;
+    gtk_widget_set_sensitive(entry, prefs->cddb_http);
     changed_cb(NULL, NULL);
 
     val = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(portw));
@@ -432,9 +436,9 @@ static void use_http_cb(GtkWidget *widget, GtkWidget *entry) {
      * use_http, set it to the default for this setting.  When switching off
      * http usage, try to guess the cddbp port.  Freedb uses 888, while
      * cddb.com uses 8880 */
-    if (prefs.cddb_http && (val == 8880 || val == 888))
+    if (prefs->cddb_http && (val == 8880 || val == 888))
       gtk_spin_button_set_value(GTK_SPIN_BUTTON(portw), 80);
-    if (!prefs.cddb_http && val == 80) {
+    if (!prefs->cddb_http && val == 80) {
       gchar *text = gtk_entry_get_text(GTK_ENTRY(gtk_object_get_data(
 				GTK_OBJECT(widget), "server-entry")));
       if (!g_strcasecmp((text + strlen(text) - 10), "freedb.org"))
@@ -444,6 +448,6 @@ static void use_http_cb(GtkWidget *widget, GtkWidget *entry) {
     }
 }
 static void httpproxy_cb(GtkWidget *widget, gpointer data) {
-    prefs.cddb_httpproxy = g_strdup(gtk_entry_get_text(GTK_ENTRY(widget)));
+    prefs->cddb_httpproxy = g_strdup(gtk_entry_get_text(GTK_ENTRY(widget)));
     changed_cb(NULL, NULL);
 }
